@@ -18,10 +18,10 @@ Ukrainian
    <ca>Ukrainian dictionary for hunspell</ca>
    <cs>Ukrainian dictionary for hunspell</cs>
    <da>Ukrainian dictionary for hunspell</da>
-   <de>Ukrainian dictionary for hunspell</de>
+   <de>Ukrainisches Wörterbuch für “Hunspell”</de>
    <el>Λεξικό Ουκρανικά για hunspell</el>
    <en>Ukrainian dictionary for hunspell</en>
-   <es_ES>Ukrainian dictionary for hunspell</es_ES>
+   <es_ES>Diccionario Ucraniano para hunspell</es_ES>
    <es>Diccionario Ucraniano para hunspell</es>
    <et>Ukrainian dictionary for hunspell</et>
    <eu>Ukrainian dictionary for hunspell</eu>
@@ -29,35 +29,36 @@ Ukrainian
    <fil_PH>Ukrainian dictionary for hunspell</fil_PH>
    <fi>Ukrainian dictionary for hunspell</fi>
    <fr_BE>Ukrainian dictionary for hunspell</fr_BE>
-   <fr>Ukrainian dictionary for hunspell</fr>
+   <fr>Ukrainien dictionnaire pour hunspell</fr>
    <gl_ES>Ukrainian dictionary for hunspell</gl_ES>
+   <gu>Ukrainian dictionary for hunspell</gu>
    <he_IL>Ukrainian dictionary for hunspell</he_IL>
    <hi>Ukrainian dictionary for hunspell</hi>
    <hr>Ukrainian dictionary for hunspell</hr>
    <hu>Ukrainian dictionary for hunspell</hu>
    <id>Ukrainian dictionary for hunspell</id>
    <is>Ukrainian dictionary for hunspell</is>
-   <it>Ukrainian dictionary for hunspell</it>
-   <ja>Ukrainian dictionary for hunspell</ja>
+   <it>Dizionario ucraino per hunspell</it>
+   <ja>Hunspell 用ウクライナ語辞書</ja>
    <kk>Ukrainian dictionary for hunspell</kk>
    <ko>Ukrainian dictionary for hunspell</ko>
    <lt>Ukrainian dictionary for hunspell</lt>
    <mk>Ukrainian dictionary for hunspell</mk>
    <mr>Ukrainian dictionary for hunspell</mr>
    <nb_NO>Ukrainian dictionary for hunspell</nb_NO>
-   <nb>Ukrainian dictionary for hunspell</nb>
+   <nb>Ukrainsk ordliste for hunspell</nb>
    <nl_BE>Ukrainian dictionary for hunspell</nl_BE>
    <nl>Ukrainian dictionary for hunspell</nl>
    <pl>Ukrainian dictionary for hunspell</pl>
-   <pt_BR>Ukrainian dictionary for hunspell</pt_BR>
-   <pt>Ukrainian dictionary for hunspell</pt>
+   <pt_BR>Dicionário Ucraniano para o hunspell (corretor ortográfico e analisador morfológico)</pt_BR>
+   <pt>Dicionário Ucraniano para hunspell</pt>
    <ro>Ukrainian dictionary for hunspell</ro>
    <ru>Ukrainian dictionary for hunspell</ru>
    <sk>Ukrainian dictionary for hunspell</sk>
    <sl>Ukrainian dictionary for hunspell</sl>
    <sq>Ukrainian dictionary for hunspell</sq>
    <sr>Ukrainian dictionary for hunspell</sr>
-   <sv>Ukrainian dictionary for hunspell</sv>
+   <sv>Ukrainsk ordbok för hunspell</sv>
    <th>Ukrainian dictionary for hunspell</th>
    <tr>Ukrainian dictionary for hunspell</tr>
    <uk>Ukrainian dictionary for hunspell</uk>
